@@ -147,7 +147,7 @@ class SlackBot(StreamHandler):
     @target_users.setter
     def target_users(self, value: List[str]):
         if value is not None:
-            if type(value) is not List:
+            if type(value) is not list:
                 value = [value]
             if any([type(user) is not str for user in value]):
                 raise TypeError(f'user IDs must be strings')
