@@ -82,26 +82,12 @@ class RTMControlManager(RTMSlackBot, ControlManager):
         )
 
         # register catch methods
-        slack.RTMClient.on(
-            event='message',
-            callback=self.start_catch,
-        )
-        slack.RTMClient.on(
-            event='message',
-            callback=self.pause_catch,
-        )
-        slack.RTMClient.on(
-            event='message',
-            callback=self.stop_catch,
-        )
-        slack.RTMClient.on(
-            event='message',
-            callback=self.resume_catch,
-        )
-        slack.RTMClient.on(
-            event='message',
-            callback=self.status_catch,
-        )
+        self.register_message_catch(self.start_catch)
+        self.register_message_catch(self.pause_catch)
+        self.register_message_catch(self.stop_catch)
+        self.register_message_catch(self.resume_catch)
+        self.register_message_catch(self.status_catch)
+        self.register_message_catch(self.help_catch)
         # store pre-parsing methods
         if pre_parsing_methods is None:
             pre_parsing_methods = self.DEFAULT_PARSING_METHODS
